package com.nokia.finance.tasks.dao.car;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

import java.util.LinkedHashMap;
import java.util.List;

@Mapper
public interface CarCxdpDao {
    /**
     * 判断是否有车效大屏需要的数据
     * @param endYearMonth 账期
     */
    @Select("""
select
    (
    select
        exists (
        select
            1
        from
            car.car_base_data_month
        where
            year_month = #{endYearMonth}))
    and (
    select
        exists (
        select
            1
        from
            car.car_fei_yong_month
        where
            year_month = #{endYearMonth}))
    and (
    select
        exists (
        select
            1
        from
            car.car_li_cheng_month
        where
            year_month = #{endYearMonth}))
    and (
    select
        exists (
        select
            1
        from
            car.car_wei_zhang
        where
            year_month = #{endYearMonth}))
""")
    boolean hasCarCxdp(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入车效大屏建设数据
     * @param startYearMonth 开始年月
     * @param endYearMonth 结束年月
     */
    @Update("""
with
a101 as (
select
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month
where year_month = #{endYearMonth}
and area_name != '省机动局'
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
),
a102 as (
select
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
),
a103 as (
select
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and area_name != '省机动局'
and che_liang_lai_yuan = '租赁车辆'
),
a104 as (
select
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
),
a105 as (
select
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
),
a106 as (
select
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
and area_name != '省机动局'
),
a107 as (
select
count(1) as wei_gui_count
from car.car_wei_gui
where year_month = #{endYearMonth}
and area_name != '省机动局'
),
a111 as (
select
'018' as area_no,
'河北省' as area_name,
'' as city_no,
'' as city_name,
a101.total,
a101.zi_you_count,
a101.zu_lin_count,
a101.qiang_xiu_count,
a101.zong_he_sheng_chan_count,
a101.yi_ban_gong_wu_count,
a101.te_zong_che_count,
a101.fu_ze_ren_count,
a102.ran_you_sum as zong_you_hao,
a104.li_cheng_sum,
case when a104.li_cheng_sum = 0 then null else a102.ran_you_sum / a104.li_cheng_sum * 100 end as bai_gong_li_you_hao,
a102.wei_xiu_sum,
case when a101.zi_you_count = 0 then null else a102.wei_xiu_sum / a101.zi_you_count end as wei_xiu_month_avg,
a107.wei_gui_count,
a105.di_xiao_count,
a106.wei_zhang_count,
a103.zu_lin_wei_xiu,
0 as shu_ju_lei_xing,
'A' as shu_ju_da_lei
from a101
cross join a102
cross join a103
cross join a104
cross join a105
cross join a106
cross join a107
),
a201 as (
select
area_no,
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month
where year_month = #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
group by area_no
),
a202 as (
select
area_no,
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
group by area_no
),
a203 as (
select
area_no,
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and che_liang_lai_yuan = '租赁车辆'
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
group by area_no
),
a204 as (
select
area_no,
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
group by area_no
),
a205 as (
select
area_no,
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
group by area_no
),
a206 as (
select
area_no,
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
group by area_no
),
a207 as (
select
area_no,
count(1) as wei_gui_count
from car.car_wei_gui
where year_month = #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
group by area_no
),
a211 as (
select
a201.area_no,
o1.name as area_name,
'' as city_no,
'' as city_name,
a201.total,
a201.zi_you_count,
a201.zu_lin_count,
a201.qiang_xiu_count,
a201.zong_he_sheng_chan_count,
a201.yi_ban_gong_wu_count,
a201.te_zong_che_count,
a201.fu_ze_ren_count,
a202.ran_you_sum as zong_you_hao,
a204.li_cheng_sum,
case when a204.li_cheng_sum = 0 then null else a202.ran_you_sum / a204.li_cheng_sum * 100 end as bai_gong_li_you_hao,
a202.wei_xiu_sum,
case when a201.zi_you_count = 0 then null else a202.wei_xiu_sum / a201.zi_you_count end as wei_xiu_month_avg,
a207.wei_gui_count,
a205.di_xiao_count,
a206.wei_zhang_count,
a203.zu_lin_wei_xiu,
1 as shu_ju_lei_xing,
'A' as shu_ju_da_lei
from a201 
left join common.organization o1 on a201.area_no = o1.id
left join a202 on a201.area_no = a202.area_no
left join a203 on a201.area_no = a203.area_no
left join a204 on a201.area_no = a204.area_no
left join a205 on a201.area_no = a205.area_no
left join a206 on a201.area_no = a206.area_no
left join a207 on a201.area_no = a207.area_no
),
a301 as (
select
area_no,
city_no,
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month 
where year_month = #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
group by area_no, city_no
),
a302 as (
select
area_no,
city_no,
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
group by area_no, city_no
),
a303 as (
select
area_no,
city_no,
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and che_liang_lai_yuan = '租赁车辆'
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
group by area_no, city_no
),
a304 as (
select
area_no,
city_no,
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month 
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
group by area_no, city_no
),
a305 as (
select
area_no,
city_no,
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
group by area_no, city_no
),
a306 as (
select
area_no,
city_no,
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
group by area_no, city_no
),
a307 as (
select
area_no,
city_no,
count(1) as wei_gui_count
from car.car_wei_gui 
where year_month = #{endYearMonth}
and area_name != '省机动局'
and area_name != '省本部'
and area_no is not null
and area_no != ''
and city_no is not null
and city_no != ''
group by area_no, city_no
),
a311 as (
select
a301.area_no,
o1.name as area_name,
a301.city_no,
o2.name as city_name,
a301.total,
a301.zi_you_count,
a301.zu_lin_count,
a301.qiang_xiu_count,
a301.zong_he_sheng_chan_count,
a301.yi_ban_gong_wu_count,
a301.te_zong_che_count,
a301.fu_ze_ren_count,
a302.ran_you_sum as zong_you_hao,
a304.li_cheng_sum,
case when a304.li_cheng_sum = 0 then null else a302.ran_you_sum / a304.li_cheng_sum * 100 end as bai_gong_li_you_hao,
a302.wei_xiu_sum,
case when a301.zi_you_count = 0 then null else a302.wei_xiu_sum / a301.zi_you_count end as wei_xiu_month_avg,
a307.wei_gui_count,
a305.di_xiao_count,
a306.wei_zhang_count,
a303.zu_lin_wei_xiu,
2 as shu_ju_lei_xing,
'A' as shu_ju_da_lei
from a301 
left join common.organization o1 on a301.area_no = o1.id
left join common.organization o2 on a301.city_no = o2.id
left join a302 on a301.area_no = a302.area_no and a301.city_no = a302.city_no
left join a303 on a301.area_no = a303.area_no and a301.city_no = a303.city_no
left join a304 on a301.area_no = a304.area_no and a301.city_no = a304.city_no
left join a305 on a301.area_no = a305.area_no and a301.city_no = a305.city_no
left join a306 on a301.area_no = a306.area_no and a301.city_no = a306.city_no
left join a307 on a301.area_no = a307.area_no and a301.city_no = a307.city_no
),
b101 as (
select
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month 
where year_month = #{endYearMonth}
and area_name = '省机动局'
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
),
b102 as (
select
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name = '省机动局'
),
b103 as (
select
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and area_name = '省机动局'
and che_liang_lai_yuan = '租赁车辆'
),
b104 as (
select
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month 
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name = '省机动局'
),
b105 as (
select
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name = '省机动局'
),
b106 as (
select
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
and area_name = '省机动局'
),
b107 as (
select
count(1) as wei_gui_count
from car.car_wei_gui 
where year_month = #{endYearMonth}
and area_name = '省机动局'
),
b111 as (
select
'018' as area_no,
'河北省' as area_name,
'' as city_no,
'' as city_name,
b101.total,
b101.zi_you_count,
b101.zu_lin_count,
b101.qiang_xiu_count,
b101.zong_he_sheng_chan_count,
b101.yi_ban_gong_wu_count,
b101.te_zong_che_count,
b101.fu_ze_ren_count,
b102.ran_you_sum as zong_you_hao,
b104.li_cheng_sum,
case when b104.li_cheng_sum = 0 then null else b102.ran_you_sum / b104.li_cheng_sum * 100 end as bai_gong_li_you_hao,
b102.wei_xiu_sum,
case when b101.zi_you_count = 0 then null else b102.wei_xiu_sum / b101.zi_you_count end as wei_xiu_month_avg,
b107.wei_gui_count,
b105.di_xiao_count,
b106.wei_zhang_count,
b103.zu_lin_wei_xiu,
0 as shu_ju_lei_xing,
'B' as shu_ju_da_lei
from b101 
cross join b102
cross join b103
cross join b104
cross join b105
cross join b106
cross join b107
),
b201 as (
select
area_no2 as area_no,
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month 
where year_month = #{endYearMonth}
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
group by area_no2
),
b202 as (
select
area_no2 as area_no,
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
b203 as (
select
area_no2 as area_no,
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and che_liang_lai_yuan = '租赁车辆'
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
b204 as (
select
area_no2 as area_no,
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month 
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
b205 as (
select
area_no2 as area_no,
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
b206 as (
select
area_no2 as area_no,
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
b207 as (
select
area_no2 as area_no,
count(1) as wei_gui_count
from car.car_wei_gui 
where year_month = #{endYearMonth}
and area_name = '省机动局'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
b211 as (
select
b201.area_no,
o1.name as area_name,
'' as city_no,
'' as city_name,
b201.total,
b201.zi_you_count,
b201.zu_lin_count,
b201.qiang_xiu_count,
b201.zong_he_sheng_chan_count,
b201.yi_ban_gong_wu_count,
b201.te_zong_che_count,
b201.fu_ze_ren_count,
b202.ran_you_sum as zong_you_hao,
b204.li_cheng_sum,
case when b204.li_cheng_sum = 0 then null else b202.ran_you_sum / b204.li_cheng_sum * 100 end as bai_gong_li_you_hao,
b202.wei_xiu_sum,
case when b201.zi_you_count = 0 then null else b202.wei_xiu_sum / b201.zi_you_count end as wei_xiu_month_avg,
b207.wei_gui_count,
b205.di_xiao_count,
b206.wei_zhang_count,
b203.zu_lin_wei_xiu,
1 as shu_ju_lei_xing,
'B' as shu_ju_da_lei
from b201 
left join common.organization o1 on b201.area_no = o1.id
left join b202 on b201.area_no = b202.area_no
left join b203 on b201.area_no = b203.area_no
left join b204 on b201.area_no = b204.area_no
left join b205 on b201.area_no = b205.area_no
left join b206 on b201.area_no = b206.area_no
left join b207 on b201.area_no = b207.area_no
),
c101 as (
select
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month
where year_month = #{endYearMonth}
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
),
c102 as (
select
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
),
c103 as (
select
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and che_liang_lai_yuan = '租赁车辆'
),
c104 as (
select
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month 
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
),
c105 as (
select
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
),
c106 as (
select
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
),
c107 as (
select
count(1) as wei_gui_count
from car.car_wei_gui 
where year_month = #{endYearMonth}
),
c111 as (
select
'018' as area_no,
'河北省' as area_name,
'' as city_no,
'' as city_name,
c101.total,
c101.zi_you_count,
c101.zu_lin_count,
c101.qiang_xiu_count,
c101.zong_he_sheng_chan_count,
c101.yi_ban_gong_wu_count,
c101.te_zong_che_count,
c101.fu_ze_ren_count,
c102.ran_you_sum as zong_you_hao,
c104.li_cheng_sum,
case when c104.li_cheng_sum = 0 then null else c102.ran_you_sum / c104.li_cheng_sum * 100 end as bai_gong_li_you_hao,
c102.wei_xiu_sum,
case when c101.zi_you_count = 0 then null else c102.wei_xiu_sum / c101.zi_you_count end as wei_xiu_month_avg,
c107.wei_gui_count,
c105.di_xiao_count,
c106.wei_zhang_count,
c103.zu_lin_wei_xiu,
0 as shu_ju_lei_xing,
'C' as shu_ju_da_lei
from c101 
cross join c102
cross join c103
cross join c104
cross join c105
cross join c106
cross join c107
),
c201 as (
select
area_no2 as area_no,
count(1) as total,
count(che_liang_lai_yuan = '自有车辆' or null) as zi_you_count,
count(che_liang_lai_yuan = '租赁车辆' or null) as zu_lin_count,
count(che_liang_shi_yong_xing_zhi = '抢修用车' or null) as qiang_xiu_count,
count(che_liang_shi_yong_xing_zhi = '综合生产用车' or null) as zong_he_sheng_chan_count,
count(che_liang_shi_yong_xing_zhi = '一般公务用车' or null) as yi_ban_gong_wu_count,
count(che_liang_shi_yong_xing_zhi = '特种车' or null) as te_zong_che_count,
count(che_liang_shi_yong_xing_zhi = '负责人用车' or null) as fu_ze_ren_count
from car.car_base_data_month 
where year_month = #{endYearMonth}
and area_no2 is not null
and area_no2 != ''
and che_liang_lai_yuan in ('自有车辆', '租赁车辆')
and che_liang_shi_yong_xing_zhi in ('抢修用车', '综合生产用车', '一般公务用车', '特种车', '负责人用车')
group by area_no2
),
c202 as (
select
area_no2 as area_no,
sum(ran_you) as ran_you_sum,
sum(wei_xiu) as wei_xiu_sum
from car.car_fei_yong_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
c203 as (
select
area_no2 as area_no,
sum(wei_xiu) as zu_lin_wei_xiu
from car.car_fei_yong_month
where year_month = #{endYearMonth}
and che_liang_lai_yuan = '租赁车辆'
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
c204 as (
select
area_no2 as area_no,
sum(zong_li_cheng) as li_cheng_sum
from car.car_li_cheng_month 
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
c205 as (
select
area_no2 as area_no,
count(1) as di_xiao_count
from car.car_di_xiao_month
where year_month >= #{startYearMonth}
and year_month <= #{endYearMonth}
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
c206 as (
select
area_no2 as area_no,
count(1) as wei_zhang_count
from car.car_wei_zhang_chang_qi
where year_month = #{endYearMonth}
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
c207 as (
select
area_no2 as area_no,
count(1) as wei_gui_count
from car.car_wei_gui 
where year_month = #{endYearMonth}
and area_no2 is not null
and area_no2 != ''
group by area_no2
),
c211 as (
select
c201.area_no,
o1.name as area_name,
'' as city_no,
'' as city_name,
c201.total,
c201.zi_you_count,
c201.zu_lin_count,
c201.qiang_xiu_count,
c201.zong_he_sheng_chan_count,
c201.yi_ban_gong_wu_count,
c201.te_zong_che_count,
c201.fu_ze_ren_count,
c202.ran_you_sum as zong_you_hao,
c204.li_cheng_sum,
case when c204.li_cheng_sum = 0 then null else c202.ran_you_sum / c204.li_cheng_sum * 100 end as bai_gong_li_you_hao,
c202.wei_xiu_sum,
case when c201.zi_you_count = 0 then null else c202.wei_xiu_sum / c201.zi_you_count end as wei_xiu_month_avg,
c207.wei_gui_count,
c205.di_xiao_count,
c206.wei_zhang_count,
c203.zu_lin_wei_xiu,
1 as shu_ju_lei_xing,
'C' as shu_ju_da_lei
from c201 
left join common.organization o1 on c201.area_no = o1.id
left join c202 on c201.area_no = c202.area_no
left join c203 on c201.area_no = c203.area_no
left join c204 on c201.area_no = c204.area_no
left join c205 on c201.area_no = c205.area_no
left join c206 on c201.area_no = c206.area_no
left join c207 on c201.area_no = c207.area_no
),
d111 as (
select * from a111
union all
select * from a211
union all
select * from a311
union all
select * from b111
union all
select * from b211
union all
select * from c111
union all
select * from c211
)
insert into publish.car_cxdp
(
acct_date,
area_no,
area_name,
city_no,
city_name,
zi_you_count,
zu_lin_count,
qiang_xiu_count,
zong_he_sheng_chan_count,
yi_ban_gong_wu_count,
te_zong_che_count,
fu_ze_ren_count,
zong_you_hao,
li_cheng_sum,
bai_gong_li_you_hao,
wei_xiu_sum,
wei_xiu_month_avg,
wei_gui_count,
di_xiao_count,
wei_zhang_count,
zu_lin_wei_xiu,
shu_ju_lei_xing,
shu_ju_da_lei
)
select
#{endYearMonth} as acct_date,
area_no,
area_name,
city_no,
city_name,
zi_you_count,
zu_lin_count,
qiang_xiu_count,
zong_he_sheng_chan_count,
yi_ban_gong_wu_count,
te_zong_che_count,
fu_ze_ren_count,
round(coalesce(zong_you_hao, 0), 2) as zong_you_hao,
round(coalesce(li_cheng_sum, 0), 2) as li_cheng_sum,
round(bai_gong_li_you_hao, 2) as bai_gong_li_you_hao,
round(coalesce(wei_xiu_sum, 0), 2) as wei_xiu_sum,
round(wei_xiu_month_avg, 2) as wei_xiu_month_avg,
coalesce(wei_gui_count, 0) as wei_gui_count,
coalesce(di_xiao_count, 0) as di_xiao_count,
coalesce(wei_zhang_count, 0) as wei_zhang_count,
round(coalesce(zu_lin_wei_xiu, 0), 2) as zu_lin_wei_xiu,
shu_ju_lei_xing,
shu_ju_da_lei
from d111
""")
    int insertCarCxdp(@Param("startYearMonth") Integer startYearMonth, @Param("endYearMonth") Integer endYearMonth);

    /**
     * 查询车效大屏建设数据
     *
     * @param endYearMonth 账期
     */
    @Select("""
select * from publish.car_cxdp where acct_date = #{endYearMonth}
""")
    List<LinkedHashMap<String, Object>> getCarCxdp(@Param("endYearMonth") Integer endYearMonth);
}
