package com.nokia.finance.tasks.dao.gdc.car;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Update;

/**
 * gdc车辆php数据库存储过程
 */
@Mapper
public interface GdcCarProcedureDao {
    /**
     * 插入车辆报废记录
     * @param endYearMonth 账期
     */
    @Update("""
insert into car_theme.wz_f_car_scrap
(
scrap_date,
card_num,
city,
dpt_sec,
grid,
year_info,
month_info
)
select
bao_fei_ri_qi as scrap_date,
che_pai_hao as card_num,
first_unit as city,
second_unit as dpt_sec,
third_unit as grid,
date_part('year', bao_fei_ri_qi) as year_info,
date_part('month', bao_fei_ri_qi) as month_info
from car.car_bao_fei
where year_month = #{endYearMonth}
""")
    int insertCarScrap(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入车辆基本信息
     * @param endYearMonth 账期
     */
    @Update("""
insert into car_theme.wz_f_car_info
(
    year_month,
    car_id,
    card_num,
    city,
    dpt_sec,
    grid,
    emissions,
    car_type,
    enabled_date,
    using_tag,
    asset_id,
    self_rent,
    is_special_car,
    emissions_type,
    oil_type,
    env_lev,
    engine_id,
    fra_id,
    init_mileage,
    own_dpt,
    driving_id,
    car_state,
    car_brand,
    car_new,
    car_move,
    allocation_in_date,
    allocation_remark
)
select
    year_month,
    year_month || '-' || che_pai_hao as car_id,
    che_pai_hao as card_num,
    first_unit as city,
    second_unit as dpt_sec,
    third_unit as grid,
    pai_liang as emissions,
    che_liang_lei_xing as car_type,
    deng_ji_ri_qi as enabled_date,
    che_liang_shi_yong_xing_zhi as using_tag,
    zi_chan_bian_hao as asset_id,
    che_liang_lai_yuan as self_rent,
    case
        when first_unit = '省公司本部'
        or position('建设部' in che_liang_suo_shu_dan_wei) > 0
        or che_liang_lei_xing = '特种车'
        or che_liang_shi_yong_xing_zhi in ('特种车', '负责人用车')
        or che_liang_lei_xing in ('特种车', '中型面包车（8-20座的面包车）', '大巴车') then 1
        else 0
    end as is_special_car,
    pai_liang_lei_xing as emissions_type,
    ran_you_biao_hao as oil_type,
    huan_bao_deng_ji as env_lev,
    fa_dong_ji_hao as engine_id,
    che_jia_hao as fra_id,
    chu_shi_li_cheng as init_mileage,
    che_liang_suo_shu_dan_wei as own_dpt,
    xing_shi_zheng_hao as driving_id,
    che_liang_zhuang_tai as car_state,
    che_liang_pin_pai as car_brand,
    car_new,
    case
        when car_move_yj_year_month is null then 0
        else 1
    end as car_move,
    case
        when car_move_yj_year_month is null then car_new_year_month
        else car_move_yj_year_month
    end as allocation_in_date,
    case
        when last_first_unit is not null
        and last_first_unit != ''
        and car_move_yj_year_month is not null then to_char(car_move_yj_date,
        'YYYY年MM月') || '从' || last_first_unit || '调配到' || first_unit
    end as allocation_remark
from
    car.car_base_data_month
where
    year_month = #{endYearMonth}
""")
    int insertCarInfo(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入一车一表
     * @param endYearMonth 账期
     */
    @Update("""
with
t101 as (
select * from car.car_base_data_month where year_month = #{endYearMonth}
),
t102 as (
select * from car.car_fei_yong_month where year_month = #{endYearMonth}
),
t103 as (
select * from car.car_li_cheng_month where year_month = #{endYearMonth}
),
t104 as (
select
year_month,
che_pai_hao,
count(1) as wei_gui_count
from car.car_wei_gui
where year_month = #{endYearMonth}
group by year_month, che_pai_hao
),
t105 as (
select
year_month,
che_pai_hao,
count(1) as yue_jie_count
from car.car_yue_jie
where year_month = #{endYearMonth}
group by year_month, che_pai_hao
),
t201 as (
select
t101.*,
t102.ran_you,
t102.wei_xiu,
t102.lu_qiao,
t102.zu_lin,
t102.bao_xian,
t102.nian_jian_fei,
t102.qi_ta,
t102.zong_fei_yong,
(select sum(zong_li_cheng) from car.car_li_cheng_month b where t101.che_pai_hao = b.che_pai_hao and b.year_month <= t101.year_month) as zong_li_cheng_total,
t103.zong_li_cheng,
t103.xing_shi_tian_shu,
t103.workday,
t103.chu_qin_lv,
t103.di_xiao,
t104.wei_gui_count,
t105.yue_jie_count
from t101
left join t102 on t101.che_pai_hao = t102.che_pai_hao and t101.year_month = t102.year_month
left join t103 on t101.che_pai_hao = t103.che_pai_hao and t101.year_month = t103.year_month
left join t104 on t101.che_pai_hao = t104.che_pai_hao and t101.year_month = t104.year_month
left join t105 on t101.che_pai_hao = t105.che_pai_hao and t101.year_month = t105.year_month
),
t202 as (
select
t201.*,
case when zong_li_cheng = 0 then null else ran_you / zong_li_cheng * 100 end as bai_gong_li_you_fei,
case when zong_li_cheng = 0 then null else wei_xiu / zong_li_cheng * 100 end as bai_gong_li_wei_xiu,
case when zong_li_cheng = 0 then null else zong_fei_yong / zong_li_cheng * 100 end as bai_gong_li_fei_yong
from t201
)
insert into car_theme.wz_f_one_car_one_table
(
car_id,
che_pai_hao,
current_mileage,
car_status,
year_info,
month_info,
oil_costs,
repair_costs,
road_bridge_costs,
rent_costs,
insurance_costs,
year_check_costs,
other_costs,
sum_costs,
sum_mileage,
attendance,
is_inefficient,
oil_per_km,
repair_per_km,
sum_costs_per_km,
violations_times,
cross_border_times,
attend_days,
work_days,
fuel_cost_per_l
)
select
    year_month || '-' || che_pai_hao as car_id,
    che_pai_hao,
    round(coalesce(zong_li_cheng_total, 0) + coalesce(chu_shi_li_cheng, 0), 2) as current_mileage,
    che_liang_zhuang_tai as car_status,
    left(cast(year_month as varchar), 4)::int4 as year_info,
    right(cast(year_month as varchar), 2)::int4 as month_info,
    case when ran_you is null then 0 else round(ran_you, 2) end as oil_costs,
    case when wei_xiu is null then 0 else round(wei_xiu, 2) end as repair_costs,
    case when lu_qiao is null then 0 else round(lu_qiao, 2) end as road_bridge_costs,
    case when zu_lin is null then 0 else round(zu_lin, 2) end as rent_costs,
    case when bao_xian is null then 0 else round(bao_xian, 2) end as insurance_costs,
    case when nian_jian_fei is null then 0 else round(nian_jian_fei, 2) end as year_check_costs,
    case when qi_ta is null then 0 else round(qi_ta, 2) end as other_costs,
    case when zong_fei_yong is null then 0 else round(zong_fei_yong, 2) end as sum_costs,
    case when zong_li_cheng is null then 0 else round(zong_li_cheng, 2) end as sum_mileage,
    round(chu_qin_lv, 4) as attendance,
    di_xiao as is_inefficient,
    round(bai_gong_li_you_fei, 2) as oil_per_km,
    round(bai_gong_li_wei_xiu, 2) as repair_per_km,
    round(bai_gong_li_fei_yong, 2) as sum_costs_per_km,
    case when wei_gui_count is null then 0 else wei_gui_count end as violations_times,
    case when yue_jie_count is null then 0 else yue_jie_count end as cross_border_times,
    case when xing_shi_tian_shu is null then 0 else xing_shi_tian_shu end as attend_days,
    workday as work_days,
    8.7 as fuel_cost_per_l
from t202
""")
    int insertOneCarOneTable(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入违规车辆
     * @param endYearMonth 账期
     */
    @Update("""
insert into car_theme.wz_f_un_dispatch_orders_cross_border
(
statistical_month,
card_num,
city,
dpt_sec,
grid,
cross_border_t,
alarm_area_des,
alarm_rule_des,
is_working,
car_type,
using_tag
)
select
year_month,
che_pai_hao,
first_unit,
second_unit,
third_unit,
yue_jie_shi_jian,
bao_jing_qu_yu_miao_shu,
bao_jing_gui_ze_miao_shu,
shi_fou_zhi_xing_zhong_yue_jie,
che_liang_lei_xing,
che_liang_shi_yong_xing_zhi
from car.car_wei_gui
where year_month = #{endYearMonth}
""")
    int insertCarWeiGui(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入无单用车报警
     * @param endYearMonth 账期
     */
    @Update("""
insert into car_theme.wz_f_un_dispatch_orders_details
(
statistical_month,
card_num,
city,
dpt_sec,
grid,
own_dpt,
violation_time_start,
violation_time_end,
violation_time_duration
)
select
year_month as statistical_month,
che_pai_hao as card_num,
first_unit as city,
second_unit as dpt_sec,
third_unit as grid,
che_liang_suo_shu_dan_wei as own_dpt,
wei_gui_kai_shi_shi_jian as violation_time_start,
wei_gui_jie_shu_shi_jian as violation_time_end,
wei_gui_chi_xu_shi_jian as violation_time_duration
from car.car_wu_dan_yong_che
where year_month = #{endYearMonth}
""")
    int insertCarWuDanYongCheBaoJing(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入无派单越界统计
     * @param startYearMonth 开始年月
     * @param endYearMonth 结束年月
     */
    @Update("""
with
t101 as (
select
    count(1) as total
from
    car.car_base_data_month
where
    year_month = #{endYearMonth}
),
t102 as (
select
    count(1) as cccs
from
    car.car_yong_che
where
    year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
),
t103 as (
select
    count(1) as wdycbjcs
from
    car.car_wu_dan_yong_che
where
    year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
),
t104 as (
select
    count(1) as yjcs
from
    car.car_yue_jie
where
    year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
),
t105 as (
select
    count(1) as wpdyjcs
from
    car.car_wei_gui
where
    year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
),
t109 as (
select
'全省' as first_unit,
'' as second_unit,
t101.total,
t102.cccs,
t103.wdycbjcs,
t104.yjcs,
t105.wpdyjcs
from t101
cross join t102
cross join t103
cross join t104
cross join t105
),
t201 as (
select
    first_unit,
    count(1) as total
from
    car.car_base_data_month
where
    first_unit is not null
    and first_unit != ''
    and year_month = #{endYearMonth}
group by
    first_unit
),
t202 as (
select
    first_unit,
    count(1) as cccs
from
    car.car_yong_che
where
    first_unit is not null
    and first_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit
),
t203 as (
select
    first_unit,
    count(1) as wdycbjcs
from
    car.car_wu_dan_yong_che
where
    first_unit is not null
    and first_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit
),
t204 as (
select
    first_unit,
    count(1) as yjcs
from
    car.car_yue_jie
where
    first_unit is not null
    and first_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit
),
t205 as (
select
    first_unit,
    count(1) as wpdyjcs
from
    car.car_wei_gui
where
    first_unit is not null
    and first_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit
),
t209 as (
select
t201.first_unit,
'' as second_unit,
t201.total,
t202.cccs,
t203.wdycbjcs,
t204.yjcs,
t205.wpdyjcs
from t201
left join t202 on t201.first_unit = t202.first_unit
left join t203 on t201.first_unit = t203.first_unit
left join t204 on t201.first_unit = t204.first_unit
left join t205 on t201.first_unit = t205.first_unit
order by t201.first_unit
),
t301 as (
select
    first_unit,
    second_unit,
    count(1) as total
from
    car.car_base_data_month
where
    first_unit is not null
    and first_unit != ''
    and second_unit is not null
    and second_unit != ''
    and year_month = #{endYearMonth}
group by
    first_unit, second_unit
),
t302 as (
select
    first_unit,
    second_unit,
    count(1) as cccs
from
    car.car_yong_che
where
    first_unit is not null
    and first_unit != ''
    and second_unit is not null
    and second_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit, second_unit
),
t303 as (
select
    first_unit,
    second_unit,
    count(1) as wdycbjcs
from
    car.car_wu_dan_yong_che
where
    first_unit is not null
    and first_unit != ''
    and second_unit is not null
    and second_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit, second_unit
),
t304 as (
select
    first_unit,
    second_unit,
    count(1) as yjcs
from
    car.car_yue_jie
where
    first_unit is not null
    and first_unit != ''
    and second_unit is not null
    and second_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit, second_unit
),
t305 as (
select
    first_unit,
    second_unit,
    count(1) as wpdyjcs
from
    car.car_wei_gui
where
    first_unit is not null
    and first_unit != ''
    and second_unit is not null
    and second_unit != ''
    and year_month >= #{startYearMonth}
    and year_month <= #{endYearMonth}
group by
    first_unit, second_unit
),
t309 as (
select
t301.first_unit,
t301.second_unit,
t301.total,
t302.cccs,
t303.wdycbjcs,
t304.yjcs,
t305.wpdyjcs
from t301
left join t302 on t301.first_unit = t302.first_unit and t301.second_unit = t302.second_unit
left join t303 on t301.first_unit = t303.first_unit and t301.second_unit = t303.second_unit
left join t304 on t301.first_unit = t304.first_unit and t301.second_unit = t304.second_unit
left join t305 on t301.first_unit = t305.first_unit and t301.second_unit = t305.second_unit
order by t301.first_unit
),
t401 as (
select * from t109
union all
select * from t209
union all
select * from t309
)
insert into car_theme.wz_f_un_dispatch_orders_cross_border_statistics
(
statistical_month,
city,
dpt_sec,
car_num,
departures_car_num_sum,
un_dispatch_num_sum,
cross_border__num_sum,
un_dispatch_cross_border_num_sum
)
select
#{endYearMonth} as statistical_month,
first_unit as city,
case when second_unit = '' then null else second_unit end as dpt_sec,
total as car_num,
coalesce(cccs, 0) as departures_car_num_sum,
coalesce(wdycbjcs, 0) as un_dispatch_num_sum,
coalesce(yjcs, 0) as cross_border__num_sum,
coalesce(wpdyjcs, 0) as un_dispatch_cross_border_num_sum
from t401
where first_unit not in ('华北基地建设部', '雄安基地建设部')
""")
    int insertCarWuPaiDanYueJieTongJi(@Param("startYearMonth") Integer startYearMonth,
                                      @Param("endYearMonth") Integer endYearMonth);
}
