package com.nokia.finance.tasks.dao.house;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

import java.util.LinkedHashMap;
import java.util.List;

@Mapper
public interface HouseFcdpDao {
    /**
     * 插入房产大屏建筑面积统计
     * @param endYearMonth 账期
     */
    @Update("""
with
t1 as (
select
    '全省' as city,
    sum(case when building_use = '综合用房' then building_area else 0 end) as area_synthesis,
    sum(case when building_use = '设备用房' then building_area else 0 end) as area_equipment,
    sum(case when building_use = '营销用房' then building_area else 0 end) as area_marketing,
    sum(case when building_use = '附属用房' then building_area else 0 end) as area_affiliate,
    sum(case when building_use = '行政用房' then building_area else 0 end) as area_administration,
    sum(case when building_use not in ('综合用房', '设备用房', '营销用房', '附属用房', '行政用房') then building_area else 0 end) as area_other,
    sum(building_area_self_use) as area_self_use,
    sum(building_area_rent) as area_rent,
    sum(building_area) - sum(building_area_self_use) - sum(building_area_rent) as area_unused,
    sum(building_area) as area_total
from
    house.building_month
where
    year_month = #{endYearMonth}
),
t2 as (
select
    city,
    sum(case when building_use = '综合用房' then building_area else 0 end) as area_synthesis,
    sum(case when building_use = '设备用房' then building_area else 0 end) as area_equipment,
    sum(case when building_use = '营销用房' then building_area else 0 end) as area_marketing,
    sum(case when building_use = '附属用房' then building_area else 0 end) as area_affiliate,
    sum(case when building_use = '行政用房' then building_area else 0 end) as area_administration,
    sum(case when building_use not in ('综合用房', '设备用房', '营销用房', '附属用房', '行政用房') then building_area else 0 end) as area_other,
    sum(building_area_self_use) as area_self_use,
    sum(building_area_rent) as area_rent,
    sum(building_area) - sum(building_area_self_use) - sum(building_area_rent) as area_unused,
    sum(building_area) as area_total
from
    house.building_month
where
    year_month = #{endYearMonth}
    and city is not null
    and city != ''
group by city
),
t3 as (
select * from t1
union all
select * from t2
)
insert into publish.house_building_area_stat
(
stat_date,
city,
area_self_use,
area_rent,
area_unused,
percent_synthesis,
percent_equipment,
percent_marketing,
percent_affiliate,
percent_administration,
percent_other,
percent_self_use,
percent_rent,
percent_unused
)
select
    #{endYearMonth} as stat_date,
    city,
    round(area_self_use / 10000, 2) as area_self_use,
    round(area_rent / 10000, 2) as area_rent,
    round(area_unused / 10000, 2) as area_unused,
    round(area_synthesis / area_total * 100, 2) as percent_synthesis,
    round(area_equipment / area_total * 100, 2) as percent_equipment,
    round(area_marketing / area_total * 100, 2) as percent_marketing,
    round(area_affiliate / area_total * 100, 2) as percent_affiliate,
    round(area_administration / area_total * 100, 2) as percent_administration,
    round(area_other / area_total * 100, 2) as percent_other,
    round(area_self_use / area_total * 100, 2) as percent_self_use,
    round(area_rent / area_total * 100, 2) as percent_rent,
    round(area_unused / area_total * 100, 2) as percent_unused
from t3
""")
    int insertHouseBuildingAreaStat(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 查询房产大屏建筑面积统计
     * @param endYearMonth 账期
     */
    @Select("""
select * from publish.house_building_area_stat where stat_date = #{endYearMonth}
""")
    List<LinkedHashMap<String, Object>> getHouseBuildingAreaStat(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 插入房产大屏建筑和土地数量统计
     * @param endYearMonth 账期
     */
    @Update("""
with
t101 as (
select
    city,
    count(1) as building_count
from
    house.building_month
where
    year_month = #{endYearMonth}
    and city is not null
    and city != ''
group by
    city
),
t102 as (
select
    city,
    count(1) as land_count
from
    house.land_month
where
    year_month = #{endYearMonth}
    and city is not null
    and city != ''
group by
    city
),
t103 as (
select
    t101.city,
    '' as district,
    t101.building_count,
    t102.land_count
from
    t101
join t102 on
    t101.city = t102.city
order by
    t101.city
),
t201 as (
select
    city,
    district,
    count(1) as building_count
from
    house.building_month
where
    year_month = #{endYearMonth}
    and city is not null
    and city != ''
    and district is not null
    and district != ''
group by
    city,
    district
),
t202 as (
select
    city,
    district,
    count(1) as land_count
from
    house.land_month
where
    year_month = #{endYearMonth}
    and city is not null
    and city != ''
    and district is not null
    and district != ''
group by
    city,
    district
),
t203 as (
select
    t201.city,
    t201.district,
    t201.building_count,
    t202.land_count
from
    t201
join t202 on
    t201.city = t202.city and t201.district = t202.district
order by
    t201.city, t201.district
),
t301 as (
select * from t103
union all
select * from t203
)
insert into publish.house_building_land_count
(
stat_date,
city,
district,
building_count,
land_count
)
select
#{endYearMonth} as stat_date,
city,
district,
building_count,
land_count
from t301
""")
    int insertHouseBuildingLandCount(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 查询房产大屏建筑面积统计
     * @param endYearMonth 账期
     */
    @Select("""
select * from publish.house_building_land_count where stat_date = #{endYearMonth}
""")
    List<LinkedHashMap<String, Object>> getHouseBuildingLandCount(@Param("endYearMonth") Integer endYearMonth);
}
