package com.nokia.finance.tasks.dao.house;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

import java.util.LinkedHashMap;
import java.util.List;

@Mapper
public interface HouseStrategyDao {
    /**
     * 判断是否有建筑数据
     * @param endYearMonth 账期
     */
    @Select("""
select exists (select 1 from house.building_month where year_month = #{endYearMonth})
""")
    boolean hasBuildingMonth(@Param("endYearMonth") Integer endYearMonth);

    @Update("""
insert into house.building_idle_strategy
(
year_month,
building_id,
first_unit,
second_unit,
third_unit,
site_num,
site_name,
address,
city_level,
city_region,
area_sector,
has_land,
site_id,
building_name,
housing_acquisition_rate,
housing_source,
acquisition_date,
house_year_began,
investor,
management_level,
building_structure,
total_floors,
assets_num,
assets_tag_num,
usage_status,
building_use,
ownership_status,
floor_area,
building_area,
building_area_self_use,
building_area_rent,
building_area_idle,
building_area_unusable,
usable_area,
usable_area_self_use,
usable_area_rent,
usable_area_idle,
usable_area_unusable,
city,
district,
lng_wgs84,
lat_wgs84,
lng_bd09,
lat_bd09,
building_img,
area_no,
area_name,
city_no,
city_name,
year_no,
month_no,
house_age,
land_name,
frontage,
courtyard,
whole_building,
property_ownership_certificate,
no_property_ownership_certificate_reason,
unrelated_assets,
community_assistant_name,
community_assistant_unit,
lng_jt,
lat_jt,
property_owner,
checked,
city_id,
district_id
)
select
year_month,
building_id,
first_unit,
second_unit,
third_unit,
site_num,
site_name,
address,
city_level,
city_region,
area_sector,
has_land,
site_id,
building_name,
housing_acquisition_rate,
housing_source,
acquisition_date,
house_year_began,
investor,
management_level,
building_structure,
total_floors,
assets_num,
assets_tag_num,
usage_status,
building_use,
ownership_status,
floor_area,
building_area,
building_area_self_use,
building_area_rent,
building_area_idle,
building_area_unusable,
usable_area,
usable_area_self_use,
usable_area_rent,
usable_area_idle,
usable_area_unusable,
city,
district,
lng_wgs84,
lat_wgs84,
lng_bd09,
lat_bd09,
building_img,
area_no,
area_name,
city_no,
city_name,
year_no,
month_no,
house_age,
land_name,
frontage,
courtyard,
whole_building,
property_ownership_certificate,
no_property_ownership_certificate_reason,
unrelated_assets,
community_assistant_name,
community_assistant_unit,
lng_jt,
lat_jt,
property_owner,
checked,
city_id,
district_id
from house.building_month
where building_area_idle > 1000
and year_month = #{endYearMonth}
order by building_area_idle desc
""")
    int insertHouseBuildingIdleStrategy(@Param("endYearMonth") Integer endYearMonth);

    @Update("""
with
t101 as (
select
    *,
    row_number() over (order by building_area_idle desc) as sort
from
    house.building_idle_strategy
where
    year_month = #{endYearMonth}
),
t201 as (
select
    area_no,
    area_name,
    city_no,
    city_name,
    'kpi_301320_155_01' as kpi_code,
    '闲置建筑面积' as kpi_name,
    round(building_area_idle, 2)::varchar as kpi_value,
    '1' as kpi_type,
    building_id as jk_object_no,
    building_name as jk_object,
    sort
from t101
),
t202 as (
select
    area_no,
    area_name,
    city_no,
    city_name,
    'kpi_301320_155_02' as kpi_code,
    '房产名称' as kpi_name,
    building_name as kpi_value,
    '0' as kpi_type,
    building_id as jk_object_no,
    building_name as jk_object,
    sort
from t101
),
t203 as (
select
    area_no,
    area_name,
    city_no,
    city_name,
    'kpi_301320_155_03' as kpi_code,
    '房产编号' as kpi_name,
    building_id as kpi_value,
    '0' as kpi_type,
    building_id as jk_object_no,
    building_name as jk_object,
    sort
from t101
),
t204 as (
select
    area_no,
    area_name,
    city_no,
    city_name,
    'kpi_301320_155_04' as kpi_code,
    '房产总建筑面积' as kpi_name,
    round(building_area, 2)::varchar as kpi_value,
    '0' as kpi_type,
    building_id as jk_object_no,
    building_name as jk_object,
    sort
from t101
),
t301 as (
select * from t201
union all
select * from t202
union all
select * from t203
union all
select * from t204
)
insert into publish.house_building_idle_strategy
(
acct_date,
dept_code,
dept_name,
strategy_code,
area_no,
area_name,
city_no,
city_name,
sale_no,
sale_name,
jk_object_no,
jk_object,
kpi_code,
kpi_name,
kpi_value,
kpi_type,
sort
)
select
#{endYearMonth} as acct_date,
'301320' as dept_code,
'河北省分公司纵横运营中心' as dept_name,
'301320_155' as strategy_code,
area_no,
area_name,
city_no,
city_name,
'' as sale_no,
'' as sale_name,
jk_object_no,
jk_object,
kpi_code,
kpi_name,
kpi_value,
kpi_type,
sort
from t301 order by sort, kpi_code
""")
    int insertPublicBuildingIdleStrategy(@Param("endYearMonth") Integer endYearMonth);

    /**
     * 查询高油耗车辆策略
     *
     * @param endYearMonth 账期
     */
    @Select("""
select
acct_date,
dept_code,
dept_name,
strategy_code,
area_no,
area_name,
city_no,
city_name,
sale_no,
sale_name,
jk_object_no,
jk_object,
kpi_code,
kpi_name,
kpi_value,
kpi_type
from publish.house_building_idle_strategy where acct_date = #{endYearMonth} order by sort, kpi_code
""")
    List<LinkedHashMap<String, Object>> getBuildingIdleStrategy(@Param("endYearMonth") Integer endYearMonth);
}
