package com.nokia.finance.tasks.jobs.car.procedure;

import com.nokia.finance.tasks.common.exception.MyRuntimeException;
import com.nokia.finance.tasks.dao.car.CarProcedureDao;
import com.nokia.finance.tasks.enums.DataStageEnum;
import com.nokia.finance.tasks.pojo.po.common.DataLogPo;
import com.nokia.finance.tasks.service.common.DataLogServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CompletableFuture;

/**
 * 车辆行驶里程月数据加工定时任务
 */
@Slf4j
@Service
public class CarLiChengMonthProcJob {
    private final CarProcedureDao carProcedureDao;
    private final DataLogServiceImpl dataLogService;

    public CarLiChengMonthProcJob(CarProcedureDao carProcedureDao, DataLogServiceImpl dataLogService) {
        this.carProcedureDao = carProcedureDao;
        this.dataLogService = dataLogService;
    }

    /**
     * 执行任务
     */
    @Scheduled(cron = "0 2 0 7 * ?")
    @Transactional(timeout = 60, rollbackFor = Exception.class)
    public void runJob() {
        log.info("执行车辆行驶里程月数据加工定时任务");
        List<DataLogPo> dataLogPoList = new ArrayList<>();
        DataLogPo dataLogPo = new DataLogPo();
        dataLogPo.setDataName("车辆行驶里程月数据加工");
        dataLogPo.setStage(DataStageEnum.JG.value);
        dataLogPo.setOperationName("车辆行驶里程月数据加工");
        dataLogPo.setObject("car.car_li_cheng_month");
        dataLogPoList.add(dataLogPo);
        try {
            // 当前日期
            LocalDate localDateNow = LocalDate.now();
            // 上个月1号
            LocalDate localDateEnd = localDateNow.minusMonths(1);
            // 年初1月1号
            LocalDate localDateStart = localDateEnd.withDayOfYear(1);
            // 结束年月
            Integer endYearMonth = Integer.valueOf(localDateEnd.format(DateTimeFormatter.ofPattern("yyyyMM")));
            // 开始年月
            Integer startYearMonth = Integer.valueOf(localDateStart.format(DateTimeFormatter.ofPattern("yyyyMM")));
            int update1 = carProcedureDao.updateCarLiChengMonthWorkday(endYearMonth);
            int update2 = carProcedureDao.updateCarLiChengMonthRiJunLiChengChuQinLv(endYearMonth);
            int update3 = carProcedureDao.updateCarLiChengMonthBaseInfo(endYearMonth);
            int update4 = carProcedureDao.updateCarLiChengMonthDiXiao(endYearMonth);
            int update5 = carProcedureDao.insertCarLiChengLeiJiMonth(startYearMonth, endYearMonth);
            carProcedureDao.insertCarDiXiaoMonth(endYearMonth);
            if (update1 == 0 || update2 == 0 || update3 == 0 || update4 == 0 || update5 == 0) {
                throw new MyRuntimeException("车辆行驶里程月数据加工定时任务失败");
            }
            dataLogPo.setDataCount(update1);
        } catch (Exception e) {
            log.error(e.toString(), e);
            dataLogPo.setStatus(0);
            dataLogPo.setExceptionInfo(e.toString());
            throw new MyRuntimeException("车辆行驶里程月数据加工定时任务失败");
        } finally {
            CompletableFuture.runAsync(() -> dataLogService.saveBatch(dataLogPoList));
        }
    }
}
