package com.nokia.finance.tasks.pojo.vo.car_report;

import com.nokia.finance.tasks.config.CarReportConfig;
import com.nokia.finance.tasks.pojo.po.car_report.CarDxPo;
import com.nokia.finance.tasks.pojo.po.car_report.CarDxUnitPo;
import lombok.Data;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.xssf.streaming.SXSSFSheet;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;

import java.io.IOException;
import java.io.OutputStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Stream;

@Data
public class CarCldxVo {
    /**
     * 低效车辆一级单位统计
     */
    private List<CarDxUnitVo> dxUnitList;

    public CarCldxVo(List<CarDxUnitPo> dxUnitList, List<CarDxPo> carDxPoList, CarReportConfig carReportConfig)
            throws IOException {
        this.dxUnitList = new ArrayList<>();
        List<String> unitList = Stream.of("石家庄", "唐山", "秦皇岛", "邯郸", "邢台", "保定", "张家口", "承德",
                "廊坊", "沧州", "衡水", "雄安", "机动局", "合计").toList();
        int unitListSize = unitList.size();
        int dxUnitListSize = dxUnitList.size();
        if (dxUnitListSize == 1) {
            for (int i = 0; i < unitListSize; i++) {
                String firstUnit = unitList.get(i);
                CarDxUnitVo carDxUnitVo = new CarDxUnitVo(String.valueOf(i + 1), firstUnit);
                this.dxUnitList.add(carDxUnitVo);
            }
        } else {
            for (int i = 0; i < unitListSize; i++) {
                String firstUnit = unitList.get(i);
                CarDxUnitVo carDxUnitVo = new CarDxUnitVo(i + 1, firstUnit);
                this.dxUnitList.add(carDxUnitVo);
                for (CarDxUnitPo carDxUnitPo : dxUnitList) {
                    if (firstUnit.equals(carDxUnitPo.getFirstUnit())) {
                        carDxUnitVo.update(carDxUnitPo);
                        break;
                    }
                }
            }
        }
        writeDxXlsx(carDxPoList, carReportConfig);
    }

    /**
     * 低效车辆xlsx
     */
    private void writeDxXlsx(List<CarDxPo> carDxPoList, CarReportConfig carReportConfig) throws IOException {
        try (SXSSFWorkbook wb = new SXSSFWorkbook();
//             FastByteArrayOutputStream os = new FastByteArrayOutputStream()
             OutputStream os = Files.newOutputStream(Paths.get(carReportConfig.getDxXlsx()))
        ) {
            DataFormat dataFormat = wb.createDataFormat();
            // 数字样式
            CellStyle numberCellStyle = wb.createCellStyle();
            numberCellStyle.setDataFormat(dataFormat.getFormat("#,##0.00"));
            numberCellStyle.setAlignment(HorizontalAlignment.RIGHT);
            // 百分比样式
            CellStyle percentCellStyle = wb.createCellStyle();
            percentCellStyle.setDataFormat(dataFormat.getFormat("0.00%"));
            percentCellStyle.setAlignment(HorizontalAlignment.RIGHT);
            // 表头样式
            CellStyle headerCellStyle = wb.createCellStyle();
            headerCellStyle.setAlignment(HorizontalAlignment.CENTER);
            headerCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
            SXSSFSheet sheet = wb.createSheet();
            AtomicInteger rowIndex = new AtomicInteger(0);
            // 表头
            Row headerRow = sheet.createRow(rowIndex.getAndIncrement());
            List<String> headers = Stream.of("车牌号", "单位", "二级", "三级", "车辆所属单位", "车辆来源", "车辆类型",
                    "车辆使用性质", "日均里程", "出勤率", "总里程", "行驶天数", "工作日天数").toList();
            int headerSize = headers.size();
            for (int i = 0; i < headerSize; i++) {
                Cell cell = headerRow.createCell(i);
                cell.setCellValue(headers.get(i));
                cell.setCellStyle(headerCellStyle);
                // 根据内容长度设置列宽
                int columnWidth = headers.get(i).length() * 256 * 2 + 256 * 5;
                sheet.setColumnWidth(i, columnWidth);
            }
            for (CarDxPo t : carDxPoList) {
                AtomicInteger columnIndex = new AtomicInteger(0);
                Row row = sheet.createRow(rowIndex.getAndIncrement());
                // 车牌号
                Cell chePaiHaoCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getChePaiHao() != null) {
                    chePaiHaoCell.setCellValue(t.getChePaiHao());
                }
                // 单位
                Cell firstUnitCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getFirstUnit() != null) {
                    firstUnitCell.setCellValue(t.getFirstUnit());
                }
                // 二级
                Cell secondUnitCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getSecondUnit() != null) {
                    secondUnitCell.setCellValue(t.getSecondUnit());
                }
                // 三级
                Cell thirdUnitCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getThirdUnit() != null) {
                    thirdUnitCell.setCellValue(t.getThirdUnit());
                }
                // 车辆所属单位
                Cell cheLiangSuoShuDanWeiCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangSuoShuDanWei() != null) {
                    cheLiangSuoShuDanWeiCell.setCellValue(t.getCheLiangSuoShuDanWei());
                }
                // 车辆来源
                Cell cheLiangLaiYuanCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangLaiYuan() != null) {
                    cheLiangLaiYuanCell.setCellValue(t.getCheLiangLaiYuan());
                }
                // 车辆类型
                Cell cheLiangLeiXingCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangLeiXing() != null) {
                    cheLiangLeiXingCell.setCellValue(t.getCheLiangLeiXing());
                }
                // 车辆使用性质
                Cell cheLiangShiYongXingZhiCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangShiYongXingZhi() != null) {
                    cheLiangShiYongXingZhiCell.setCellValue(t.getCheLiangShiYongXingZhi());
                }
                // 日均里程
                Cell riJunLiChengSumCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getRiJunLiChengSum() != null) {
                    riJunLiChengSumCell.setCellValue(t.getRiJunLiChengSum().doubleValue());
                }
                riJunLiChengSumCell.setCellStyle(numberCellStyle);
                // 出勤率
                Cell chuQinLvSumCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getChuQinLvSum() != null) {
                    chuQinLvSumCell.setCellValue(t.getChuQinLvSum().doubleValue());
                }
                chuQinLvSumCell.setCellStyle(percentCellStyle);
                // 总里程
                Cell zongLiChengSumCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getZongLiChengSum() != null) {
                    zongLiChengSumCell.setCellValue(t.getZongLiChengSum().doubleValue());
                }
                zongLiChengSumCell.setCellStyle(numberCellStyle);
                // 行驶天数
                Cell xingShiTianShuSumCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getXingShiTianShuSum() != null) {
                    xingShiTianShuSumCell.setCellValue(t.getXingShiTianShuSum());
                }
                // 工作日天数
                Cell workdaySumCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getWorkdaySum() != null) {
                    workdaySumCell.setCellValue(t.getWorkdaySum());
                }
            }
            wb.write(os);
        }
    }
}
