package com.nokia.finance.tasks.pojo.vo.car_report;

import com.nokia.finance.tasks.config.CarReportConfig;
import com.nokia.finance.tasks.pojo.po.car_report.CarZywxycPo;
import com.nokia.finance.tasks.pojo.po.car_report.CarZywxycUnitPo;
import lombok.Data;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.xssf.streaming.SXSSFSheet;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;

import java.io.IOException;
import java.io.OutputStream;
import java.math.RoundingMode;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Stream;

@Data
public class CarZyycwxVo {
    /**
     * 自有车辆异常维修费一级单位统计
     */
    private List<CarZywxycUnitVo> zywxycUnitList;

    public CarZyycwxVo(List<CarZywxycUnitPo> zywxycUnitList, List<CarZywxycPo> carZywxycPoList,
                       CarReportConfig carReportConfig) throws IOException {
        this.zywxycUnitList = new ArrayList<>();
        for (CarZywxycUnitPo carZywxycUnitPo : zywxycUnitList) {
            this.zywxycUnitList.add(new CarZywxycUnitVo(carZywxycUnitPo));
        }
        writeZywxycXlsx(carZywxycPoList, carReportConfig);
    }

    /**
     * 自有车辆异常维修费xlsx
     */
    private void writeZywxycXlsx(List<CarZywxycPo> carZywxycPoList, CarReportConfig carReportConfig) throws IOException {
        try (SXSSFWorkbook wb = new SXSSFWorkbook();
//             FastByteArrayOutputStream os = new FastByteArrayOutputStream()
             OutputStream os = Files.newOutputStream(Paths.get(carReportConfig.getZywxycXlsx()))
        ) {
            DataFormat dataFormat = wb.createDataFormat();
            // 数字样式
            CellStyle numberCellStyle = wb.createCellStyle();
            numberCellStyle.setDataFormat(dataFormat.getFormat("#,##0.00"));
            numberCellStyle.setAlignment(HorizontalAlignment.RIGHT);
            // 日期样式
            CellStyle dateCellStyle = wb.createCellStyle();
            dateCellStyle.setDataFormat(dataFormat.getFormat("yyyy/MM/dd"));
            dateCellStyle.setAlignment(HorizontalAlignment.CENTER);
            // 表头样式
            CellStyle headerCellStyle = wb.createCellStyle();
            headerCellStyle.setAlignment(HorizontalAlignment.CENTER);
            headerCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
            SXSSFSheet sheet = wb.createSheet();
            AtomicInteger rowIndex = new AtomicInteger(0);
            // 表头
            Row headerRow = sheet.createRow(rowIndex.getAndIncrement());
            List<String> headers = Stream.of("车牌号", "单位", "二级", "三级", "车辆所属单位", "累计维修", "排名",
                    "车龄", "登记日期", "车辆来源", "车辆类型", "车辆使用性质").toList();
            int headerSize = headers.size();
            for (int i = 0; i < headerSize; i++) {
                Cell cell = headerRow.createCell(i);
                cell.setCellValue(headers.get(i));
                cell.setCellStyle(headerCellStyle);
                // 根据内容长度设置列宽
                int columnWidth = headers.get(i).length() * 256 * 2 + 256 * 5;
                sheet.setColumnWidth(i, columnWidth);
            }
            for (CarZywxycPo t : carZywxycPoList) {
                AtomicInteger columnIndex = new AtomicInteger(0);
                Row row = sheet.createRow(rowIndex.getAndIncrement());
                // 车牌号
                Cell chePaiHaoCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getChePaiHao() != null) {
                    chePaiHaoCell.setCellValue(t.getChePaiHao());
                }
                // 单位
                Cell firstUnitCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getFirstUnit() != null) {
                    firstUnitCell.setCellValue(t.getFirstUnit());
                }
                // 二级
                Cell secondUnitCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getSecondUnit() != null) {
                    secondUnitCell.setCellValue(t.getSecondUnit());
                }
                // 三级
                Cell thirdUnitCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getThirdUnit() != null) {
                    thirdUnitCell.setCellValue(t.getThirdUnit());
                }
                // 车辆所属单位
                Cell cheLiangSuoShuDanWeiCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangSuoShuDanWei() != null) {
                    cheLiangSuoShuDanWeiCell.setCellValue(t.getCheLiangSuoShuDanWei());
                }
                // 累计维修
                Cell weiXiuSumCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getWeiXiuSum() != null) {
                    weiXiuSumCell.setCellValue(t.getWeiXiuSum().doubleValue());
                }
                weiXiuSumCell.setCellStyle(numberCellStyle);
                // 排名
                Cell weiXiuRankCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getWeiXiuRank() != null) {
                    weiXiuRankCell.setCellValue(t.getWeiXiuRank());
                }
                // 车龄
                Cell cheLingCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLing() != null) {
                    cheLingCell.setCellValue(t.getCheLing().setScale(0, RoundingMode.CEILING).intValue());
                }
                // 登记日期
                Cell dengJiRiQiCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getDengJiRiQi() != null) {
                    dengJiRiQiCell.setCellValue(t.getDengJiRiQi());
                }
                dengJiRiQiCell.setCellStyle(dateCellStyle);
                // 车辆来源
                Cell cheLiangLaiYuanCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangLaiYuan() != null) {
                    cheLiangLaiYuanCell.setCellValue(t.getCheLiangLaiYuan());
                }
                // 车辆类型
                Cell cheLiangLeiXingCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangLeiXing() != null) {
                    cheLiangLeiXingCell.setCellValue(t.getCheLiangLeiXing());
                }
                // 车辆使用性质
                Cell cheLiangShiYongXingZhiCell = row.createCell(columnIndex.getAndIncrement());
                if (t.getCheLiangShiYongXingZhi() != null) {
                    cheLiangShiYongXingZhiCell.setCellValue(t.getCheLiangShiYongXingZhi());
                }
            }
            wb.write(os);
        }
    }
}
