package com.nokia.finance.tasks.pojo.vo.house_report;

import com.nokia.finance.tasks.pojo.po.house_report.HouseBuildingStatPo;
import lombok.Data;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;

@Data
public class HouseFczyztsyxlVo {
    /**
     * 全省房屋建筑面积闲置率超过20%的单位个数
     */
    private String xzlGtCount;
    /**
     * 闲置率最高单位
     */
    private String xzlMaxUnit;
    /**
     * 最高闲置率
     */
    private String xzlMaxPercent;
    /**
     * 表格
     */
    private List<HouseFczyztsyxlTableVo> table;

    public HouseFczyztsyxlVo(List<HouseBuildingStatPo> list) {
        this.table = new ArrayList<>();
        DecimalFormat integerFormat = new DecimalFormat("#,###");
        DecimalFormat percentFormat = new DecimalFormat("0%");
        BigDecimal jzmj = BigDecimal.ZERO;
        for (HouseBuildingStatPo t : list) {
            this.table.add(new HouseFczyztsyxlTableVo(t));
            if ("合计".equals(t.getAreaName())) {
                jzmj = t.getZmj();
            }
        }
        if (jzmj.compareTo(BigDecimal.ZERO) == 0) {
            this.xzlGtCount = HouseReportVo.PLACEHOLDER;
            this.xzlMaxUnit = HouseReportVo.PLACEHOLDER;
            this.xzlMaxPercent = HouseReportVo.PLACEHOLDER;
            this.table = new ArrayList<>();
            for (HouseBuildingStatPo t : list) {
                this.table.add(new HouseFczyztsyxlTableVo(t.getAreaName()));
            }
            return;
        }
        this.xzlGtCount = integerFormat.format(list.stream()
                .filter(t -> !"合计".equals(t.getAreaName()) && t.getXzl().compareTo(new BigDecimal("0.2")) > 0)
                .count());
        list.stream().filter(t -> !"合计".equals(t.getAreaName()))
                .max(Comparator.comparing(HouseBuildingStatPo::getXzl)).ifPresent(t -> {
            this.xzlMaxUnit = t.getAreaName();
            this.xzlMaxPercent = percentFormat.format(t.getXzl().setScale(1, RoundingMode.HALF_UP));
        });
    }
}
