package com.nokia.finance.tasks.pojo.vo.house_report;

import com.nokia.finance.tasks.pojo.po.house_report.HouseFangWuWeiXiuZongTiQingKuangPo;
import lombok.Data;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

@Data
public class HouseFwwxztqkVo {
    /**
     * 全省房屋维修费用
     */
    private String ljwxf;
    /**
     * 同比增减
     */
    private String tbzj;
    /**
     * 同比百分比
     */
    private String tbbfb;
    /**
     * 维修费同比下降单位数量
     */
    private String tbxjUnitCount;
    /**
     * 本年维修费同比增长
     */
    private String tbzzUnit;
    /**
     * 表格
     */
    private List<HouseFwwxztqkTableVo> table;
    /**
     * 整体同比
     */
    private String zttb;
    /**
     * 增长幅度较大单位
     */
    private String tbzzjdUnit;

    public HouseFwwxztqkVo(List<HouseFangWuWeiXiuZongTiQingKuangPo> list) {
        this.table = new ArrayList<>();
        List<String> unitList = Stream.of("石家庄", "唐山", "秦皇岛", "邯郸", "邢台", "保定", "张家口", "承德",
                "廊坊", "沧州", "衡水", "雄安", "本部（含传输局）", "全省").toList();
        if (CollectionUtils.isEmpty(list)) {
            this.ljwxf = HouseReportVo.PLACEHOLDER;
            this.tbzj = HouseReportVo.PLACEHOLDER;
            this.tbbfb = HouseReportVo.PLACEHOLDER;
            this.tbxjUnitCount = HouseReportVo.PLACEHOLDER;
            this.tbzzUnit = HouseReportVo.PLACEHOLDER;
            this.zttb = HouseReportVo.PLACEHOLDER;
            this.tbzzjdUnit = HouseReportVo.PLACEHOLDER;
            for (String unit : unitList) {
                this.table.add(new HouseFwwxztqkTableVo(unit));
            }
            return;
        }
        for (String unit : unitList) {
            HouseFwwxztqkTableVo x = new HouseFwwxztqkTableVo(unit);
            this.table.add(x);
            for (HouseFangWuWeiXiuZongTiQingKuangPo t : list) {
                if ("全省".equals(t.getUnit())) {
                    DecimalFormat integerFormat = new DecimalFormat("#,###");
                    DecimalFormat percentFormat = new DecimalFormat("0%");
                    this.ljwxf = integerFormat.format(t.getTyWx());
                    this.tbzj = (t.getYoy().compareTo(BigDecimal.ZERO) >= 0 ? "增长" : "减少")
                            + integerFormat.format(t.getYoy().abs());
                    this.tbbfb = (t.getYoyPercent().compareTo(BigDecimal.ZERO) >= 0 ? "增长" : "减少")
                            + percentFormat.format(t.getYoyPercent().abs());
                    this.zttb = (t.getYoy().compareTo(BigDecimal.ZERO) >= 0 ? "增长" : "下降");
                }
                if (unit.equals(t.getUnit())) {
                    x.update(t);
                    break;
                }
            }
        }
        this.tbxjUnitCount = String.valueOf(list.stream()
                .filter(t -> !"全省".equals(t.getUnit()) && t.getYoy().compareTo(BigDecimal.ZERO) < 0).count());
        List<HouseFangWuWeiXiuZongTiQingKuangPo> tbzzList = list.stream()
                .filter(t -> !"全省".equals(t.getUnit()) && t.getYoyPercent().compareTo(BigDecimal.ZERO) > 0)
                .sorted(Comparator.comparing(HouseFangWuWeiXiuZongTiQingKuangPo::getYoyPercent).reversed()).toList();
        if (CollectionUtils.isEmpty(tbzzList)) {
            this.tbzzUnit = "无单位";
            this.tbzzjdUnit = "无单位";
            return;
        }
        this.tbzzUnit = tbzzList.stream()
                .map(HouseFangWuWeiXiuZongTiQingKuangPo::getUnit).collect(Collectors.joining("、"));
        if (tbzzList.size() == 1) {
            this.tbzzjdUnit = tbzzList.get(0).getUnit();
        } else {
            BigDecimal median;
            List<BigDecimal> l = tbzzList.stream().map(HouseFangWuWeiXiuZongTiQingKuangPo::getYoyPercent).sorted().toList();
            int size = l.size();
            if (size % 2 == 0) {
                int midIndex = size / 2;
                BigDecimal firstMidValue = l.get(midIndex - 1);
                BigDecimal secondMidValue = l.get(midIndex);
                median = firstMidValue.add(secondMidValue).divide(new BigDecimal("2"), RoundingMode.HALF_UP);
            } else {
                int midIndex = size / 2;
                median = l.get(midIndex);
            }
            this.tbzzjdUnit = tbzzList.stream().filter(t -> t.getYoyPercent().compareTo(median) > 0)
                    .sorted(Comparator.comparing(HouseFangWuWeiXiuZongTiQingKuangPo::getYoyPercent).reversed())
                    .map(HouseFangWuWeiXiuZongTiQingKuangPo::getUnit).collect(Collectors.joining("、"));
        }
    }
}
