package com.nokia.finance.tasks.utils;

import com.nokia.finance.tasks.common.exception.MyRuntimeException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.exec.CommandLine;
import org.apache.commons.exec.DefaultExecutor;
import org.apache.commons.exec.ExecuteWatchdog;
import org.apache.commons.exec.PumpStreamHandler;
import org.springframework.util.StringUtils;

import java.io.ByteArrayOutputStream;
import java.time.Duration;

/**
 * libreoffice工具
 */
@Slf4j
public class OfficeUtil {

    /**
     * 转pdf
     * @param outDir 输出文件夹
     * @param files 输入文件
     * @param timeout 超时分钟
     */
    public static void toPdf(String outDir, String files, Long timeout) {
        String command = "docker exec libreoffice soffice --headless --convert-to pdf --outdir";
        CommandLine commandLine = CommandLine.parse(command);
        commandLine.addArgument(outDir);
        commandLine.addArgument(files);
        log.info("command: {}", commandLine);
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        ByteArrayOutputStream err = new ByteArrayOutputStream();
        DefaultExecutor executor = DefaultExecutor.builder().get();
        ExecuteWatchdog watchdog = ExecuteWatchdog.builder().setTimeout(Duration.ofMinutes(timeout)).get();
        executor.setWatchdog(watchdog);
        PumpStreamHandler streamHandler = new PumpStreamHandler(out, err);
        executor.setStreamHandler(streamHandler);
        try {
            int exitValue = executor.execute(commandLine);
            log.info("exitValue: {}", exitValue);
            String errString = err.toString();
            if (StringUtils.hasText(errString)) {
                throw new MyRuntimeException();
            }
        } catch (Exception e) {
            if (watchdog.killedProcess()) {
                throw new MyRuntimeException("执行超时", e);
            }
            throw new MyRuntimeException(e);
        } finally {
            String outString = out.toString();
            String errString = err.toString();
            log.info("out: {}", outString);
            if (StringUtils.hasText(errString)) {
                log.error("err: {}", errString);
            }
        }
    }
}
